import { MarkAttrs } from '@pintora/core'
import { EdgeType, getParamRulesFromConfig, interpreteConfigs, makeConfigurator } from '../util/config'
import { DEFAULT_FONT_FAMILY } from '../util/text'
import { PALETTE } from '../util/theme'

export type DOTConf = {
  diagramPadding: number

  layoutDirection: string
  ranksep: number
  nodesep: number
  edgesep: number
  edgeType: EdgeType

  nodePadding: number
  nodeBorderRadius: number

  backgroundColor: string

  labelTextColor: string
  nodeBorderColor: string
  edgeColor: string

  fontSize: number
  fontWeight: MarkAttrs['fontWeight']
  fontFamily: string
}

export const defaultConfig: DOTConf = {
  diagramPadding: 15,

  layoutDirection: 'TB',
  ranksep: 20,
  nodesep: 20,
  edgesep: 10,
  edgeType: 'polyline',

  nodePadding: 8,
  nodeBorderRadius: 2,

  backgroundColor: PALETTE.white,

  labelTextColor: PALETTE.normalDark,
  nodeBorderColor: PALETTE.normalDark,
  edgeColor: PALETTE.normalDark,

  fontSize: 14,
  fontWeight: 'normal',
  fontFamily: DEFAULT_FONT_FAMILY,
} as const

export const DOT_PARAM_DIRECTIVE_RULES = {
  ...getParamRulesFromConfig(defaultConfig),
} as const

export const configKey = 'dot'

const configurator = makeConfigurator<DOTConf>({
  defaultConfig,
  configKey,
  getConfigFromParamDirectives(configParams) {
    return interpreteConfigs(DOT_PARAM_DIRECTIVE_RULES, configParams)
  },
  getConfigFromTheme(t) {
    return {
      backgroundColor: t.canvasBackground,
      labelTextColor: t.textColor,
      nodeBorderColor: t.primaryLineColor,
      edgeColor: t.primaryLineColor,
    }
  },
})

export const getConf = configurator.getConfig
